@@ -1,10 +1,10 @@
-__version__ = "0.0.9"
+__version__ = "0.0.10"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.0.9)'
+__git_branch__ = '(detached from v0.0.10)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'f57e33f0978c32b8d11a4cf41879251e049d67b8'
-__git_head_subject__ = 'buildout.cfg: changed isolated python version to v2.7.6.6'
+__git_head_hash__ = 'b2211d9488c41691cdd6f5632449704178b4a611'
+__git_head_subject__ = 'update homepage'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
